'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var _Object$keys = _interopDefault(require('babel-runtime/core-js/object/keys'));
var etpl = _interopDefault(require('etpl'));
var fs = _interopDefault(require('fs'));
var path = _interopDefault(require('path'));
var babel = _interopDefault(require('babel-core'));

var cwd = process.cwd();


/**
                          * 获取时间戳版本号
                          *
                          * @return {string} 版本号
                          */
function getVersion() {
    var d = new Date();
    var p = function p(value) {
        return value < 10 ? '0' + value : value;
    };

    return '' +
    d.getFullYear() +
    p(d.getMonth() + 1) +
    p(d.getDate()) +
    p(d.getHours()) +
    p(d.getMinutes()) +
    p(d.getSeconds());
}

/**
   * babel 编译
   *
   * @param {string} source 源代码
   * @return {string} 编译后的代码
   */
function babelCompiler(source) {
    return babel.transform(source, {
        comments: false,
        minified: true,
        plugins: [
        'transform-runtime',
        'external-helpers'],

        presets: [
        [
        'env',
        {
            targets: {
                node: 3 },

            modules: false }]] }).



    code;
}

/**
   * sw Register 插件
   *
   * @constructor
   * @param {Object} options 参数
   */
function SwRegisterPlugin() {var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var filePath = path.resolve(cwd, options.filePath || './src/sw-register.js');

    if (!fs.existsSync(filePath)) {
        filePath = path.resolve(__dirname, '..', 'templates', 'sw-register.js');
    }
    this.filePath = filePath;
    this.fileName = path.basename(filePath);
    this.swPath = options.swPath || '/service-worker.js';
    this.version = options.version || getVersion();
}



SwRegisterPlugin.prototype.apply = function (compiler) {

    var me = this;
    var swRegisterEntryFilePath = path.resolve(__dirname, '..', 'templates', 'sw-register-entry.js.tpl');
    var swRegisterFilePath = me.filePath;

    compiler.plugin('emit', function (compilation, callback) {
        _Object$keys(compilation.assets).forEach(function (asset) {

            if (asset.indexOf('.html') > -1) {
                var htmlContent = compilation.assets[asset].source();
                var swRegisterEntryFileTpl = fs.readFileSync(swRegisterEntryFilePath, 'utf-8');
                var swRegisterEntryFileContent = etpl.compile(swRegisterEntryFileTpl)(me);
                var con = fs.readFileSync(swRegisterFilePath, 'utf-8');

                con = babelCompiler(con).
                replace(
                /serviceWorker\.register\(.*?\)/g,
                'serviceWorker.register("' + me.swPath + '?v=' + me.version + '")');


                htmlContent = htmlContent.replace(/<\/body>/, swRegisterEntryFileContent + '</body>');

                compilation.assets[asset] = {
                    source() {
                        return htmlContent;
                    },
                    size() {
                        return htmlContent.length;
                    } };


                compilation.assets[me.fileName] = {
                    source() {
                        return con;
                    },
                    size() {
                        return con.length;
                    } };

            }
        });
        callback();
    });

};

module.exports = SwRegisterPlugin;
//# sourceMappingURL=index.js.map
